==> uxarray-2024.10.1.tar.gz: uxarray-2024.10.1/CODE_OF_CONDUCT.md <==
# Code of Conduct

## Our Pledge

We, as members, contributors, creators, stewards, and maintainers, i.e. all the
participants, of UXarray pledge to make participation in our software, system
or hardware project and community a safe, healthy, open, productive, welcoming,
diverse, inclusive, and harassment-free experience for everyone, regardless of
age, body size, visible or invisible disability, ethnicity, sex characteristics,
gender identity and expression, level of experience, education, socio-economic
status, nationality, personal appearance, race, caste, color, religion, or
sexual identity and orientation, as well as any other characteristic protected
under applicable US federal or state law.

All participants are required to abide by this Code of Conduct.

## Our Standards

Examples of behaviors that contribute to a positive environment for our community
include:

- Demonstrating empathy and kindness toward other people
- Being considerate and respectful of and collaborative with differing opinions,
  viewpoints, and experiences
- Acknowledging the contributions of others
- Giving and gracefully accepting constructive feedback
- Accepting responsibility and apologizing to those affected by our mistakes,
  and learning from the experience
- Focusing on what is best not just for us as individuals, but for the overall
  community
- Respecting the rules and policies of the project and venue

Examples of unacceptable behavior include, but are not limited to:

- Public or private harassment, intimidation, or discrimination in any form
- Physical, verbal, or written abuse by anyone to anyone, including repeated
  use of pronouns other than those requested
- The use of sexualized language or imagery, and sexual attention or advances
  of any kind
- Personal attacks directed at other guests, members, participants, etc.
- Publishing others’ private information, such as a physical or electronic
  address, without explicit permission
- Alarming, intimidating, threatening, or hostile comments or conduct
- Threatening or stalking anyone, including a participant
- Trolling, insulting or derogatory comments, and personal or political attacks
- Other conduct which could reasonably be considered inappropriate in a
  professional setting

## Enforcement Responsibilities

Community leaders are responsible for clarifying and enforcing our standards of
acceptable behavior and will take appropriate and fair corrective action in
response to any behavior that they deem inappropriate, threatening, offensive,
or harmful.

Community leaders have the right and responsibility to remove, edit, or reject
comments, commits, code, wiki edits, issues, and other contributions that are
not aligned to this Code of Conduct, and will communicate reasons for moderation
decisions when appropriate.

## Scope

This Code of Conduct applies to all community spaces managed by UXarray whether
they be physical, online or face-to-face, and also applies when an individual is
officially representing the community in public spaces. This includes but is not
limited to project code, code repository, associated web pages, documentation,
mailing lists, project websites and wiki pages, issue tracker, meetings, telecons,
events, use of official email or social media accounts, and any other forums
created by the project team which the community uses for communication. In
addition, violations of this Code of Conduct outside these spaces may affect a
person's ability to participate within them. Representation of a project may be
further defined and clarified by project maintainers.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported to the the `@UXARRAY/uxarray-dev` GitHub handle as the community leaders
in this group can view and manage the reported content, and hence are responsible
for enforcement.

All complaints will be reviewed and investigated promptly and fairly.

All community leaders are obligated to respect the privacy and security of the
reporter of any incident.

## Enforcement Guidelines

Community leaders will follow these Community Impact Guidelines in determining
the consequences for any action they deem in violation of this Code of Conduct:

### 1. Correction

**Community Impact**: Use of inappropriate language or other behavior deemed
unprofessional or unwelcome in the community.

**Consequence**: A private, written warning from community leaders, providing
clarity around the nature of the violation and an explanation of why the
behavior was inappropriate. A public apology may be requested.

### 2. Warning

**Community Impact**: A violation through a single incident or series of
actions.

**Consequence**: A warning with consequences for continued behavior. No
interaction with the people involved, including unsolicited interaction with
those enforcing the Code of Conduct, for a specified period of time. This
includes avoiding interactions in community spaces as well as external channels
like social media. Violating these terms may lead to a temporary or permanent
ban.

### 3. Temporary Ban

**Community Impact**: A serious violation of community standards, including
sustained inappropriate behavior.

**Consequence**: A temporary ban from any sort of interaction or public
communication with the community for a specified period of time. No public or
private interaction with the people involved, including unsolicited interaction
with those enforcing the Code of Conduct, is allowed during this period.
Violating these terms may lead to a permanent ban.

### 4. Permanent Ban

**Community Impact**: Demonstrating a pattern of violation of community
standards, including sustained inappropriate behavior, harassment of an
individual, or aggression toward or disparagement of classes of individuals.

**Consequence**: A permanent ban from any sort of public interaction within the
community.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant Code of Conduct,
version 2.1][homepage], [version 2.1][v2.1].

Community Impact Guidelines were inspired by
[Mozilla's code of conduct enforcement ladder][Mozilla CoC].

For answers to common questions about this code of conduct, see the FAQ at
[https://www.contributor-covenant.org/faq][FAQ]. Translations are available at
[https://www.contributor-covenant.org/translations][translations].

[homepage]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
[Mozilla CoC]: https://github.com/mozilla/diversity
[FAQ]: https://www.contributor-covenant.org/faq
[translations]: https://www.contributor-covenant.org/translations

==> uxarray-2025.2.0.tar.gz: uxarray-2025.2.0/CODE_OF_CONDUCT.md <==
# Code of Conduct

## Our Pledge

We, as members, contributors, creators, stewards, and maintainers, i.e. all the
participants, of UXarray pledge to make participation in our software, system
or hardware project and community a safe, healthy, open, productive, and
harassment-free experience for everyone, protected under applicable US federal
or state law.

All participants are required to abide by this Code of Conduct.

## Our Standards

Examples of behaviors that contribute to a positive environment for our community
include:

- Demonstrating empathy and kindness toward other people
- Being considerate and respectful of and collaborative with differing opinions,
  viewpoints, and experiences
- Acknowledging the contributions of others
- Giving and gracefully accepting constructive feedback
- Accepting responsibility and apologizing to those affected by our mistakes,
  and learning from the experience
- Focusing on what is best not just for us as individuals, but for the overall
  community
- Respecting the rules and policies of the project and venue

Examples of unacceptable behavior include, but are not limited to:

- Public or private harassment or intimidation in any form
- Physical, verbal, or written abuse by anyone to anyone
- The use of sexualized language or imagery, and sexual attention or advances
  of any kind
- Personal attacks directed at other guests, members, participants, etc.
- Publishing others’ private information, such as a physical or electronic
  address, without explicit permission
- Alarming, intimidating, threatening, or hostile comments or conduct
- Threatening or stalking anyone, including a participant
- Trolling, insulting or derogatory comments, and personal or political attacks
- Other conduct which could reasonably be considered inappropriate in a
  professional setting

## Enforcement Responsibilities

Community leaders are responsible for clarifying and enforcing our standards of
acceptable behavior and will take appropriate and fair corrective action in
response to any behavior that they deem inappropriate, threatening, offensive,
or harmful.

Community leaders have the right and responsibility to remove, edit, or reject
comments, commits, code, wiki edits, issues, and other contributions that are
not aligned to this Code of Conduct, and will communicate reasons for moderation
decisions when appropriate.

## Scope

This Code of Conduct applies to all community spaces managed by UXarray whether
they be physical, online or face-to-face, and also applies when an individual is
officially representing the community in public spaces. This includes but is not
limited to project code, code repository, associated web pages, documentation,
mailing lists, project websites and wiki pages, issue tracker, meetings, telecons,
events, use of official email or social media accounts, and any other forums
created by the project team which the community uses for communication. In
addition, violations of this Code of Conduct outside these spaces may affect a
person's ability to participate within them. Representation of a project may be
further defined and clarified by project maintainers.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported to the the `@UXARRAY/uxarray-dev` GitHub handle as the community leaders
in this group can view and manage the reported content, and hence are responsible
for enforcement.

All complaints will be reviewed and investigated promptly and fairly.

All community leaders are obligated to respect the privacy and security of the
reporter of any incident.

## Enforcement Guidelines

Community leaders will follow these Community Impact Guidelines in determining
the consequences for any action they deem in violation of this Code of Conduct:

### 1. Correction

**Community Impact**: Use of inappropriate language or other behavior deemed
unprofessional or unwelcome in the community.

**Consequence**: A private, written warning from community leaders, providing
clarity around the nature of the violation and an explanation of why the
behavior was inappropriate. A public apology may be requested.

### 2. Warning

**Community Impact**: A violation through a single incident or series of
actions.

**Consequence**: A warning with consequences for continued behavior. No
interaction with the people involved, including unsolicited interaction with
those enforcing the Code of Conduct, for a specified period of time. This
includes avoiding interactions in community spaces as well as external channels
like social media. Violating these terms may lead to a temporary or permanent
ban.

### 3. Temporary Ban

**Community Impact**: A serious violation of community standards, including
sustained inappropriate behavior.

**Consequence**: A temporary ban from any sort of interaction or public
communication with the community for a specified period of time. No public or
private interaction with the people involved, including unsolicited interaction
with those enforcing the Code of Conduct, is allowed during this period.
Violating these terms may lead to a permanent ban.

### 4. Permanent Ban

**Community Impact**: Demonstrating a pattern of violation of community
standards, including sustained inappropriate behavior, harassment of an
individual, or aggression toward or disparagement of individuals.

**Consequence**: A permanent ban from any sort of public interaction within the
community.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant Code of Conduct,
version 2.1][homepage], [version 2.1][v2.1].

Community Impact Guidelines were inspired by
[Mozilla's code of conduct enforcement ladder][Mozilla CoC].

For answers to common questions about this code of conduct, see the FAQ at
[https://www.contributor-covenant.org/faq][FAQ]. Translations are available at
[https://www.contributor-covenant.org/translations][translations].

[homepage]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
[Mozilla CoC]: https://github.com/mozilla/diversity
[FAQ]: https://www.contributor-covenant.org/faq
[translations]: https://www.contributor-covenant.org/translations
